using Asp.Versioning;
using Dto;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Shared;

namespace API.Controllers;

[Route("api/v{version:apiVersion}/[controller]")]
[Authorize]
[ApiVersion("1.0")]
[ApiController]
public class NotepadController(ILogger<NotepadController> logger, INotePadService<NotepadDto> notePadService) : ControllerBase
{
    [HttpGet("notePad/{id:int}")]
    [ProducesResponseType(typeof(UserDto), 200)]
    [ProducesResponseType(typeof(string), 404)]
    public IActionResult GetNotePadById(int id)
    {
        try
        {
            logger.LogInformation(" [INFORMATION] Le bloc note avec l'id {id} a été trouvé.", id);
            return Ok(notePadService.GetNotePadById(id));
        }
        catch (ArgumentException)
        {
            logger.LogError("[ERREUR] Aucun bloc n'a été trouvé pour l'id {id}", id);
            return NotFound();
        }
    }
}